@@ -172,6 +172,39 @@ class FormTemplate(FormContainer):
         )
 
 
+@template('crudlfap/api.html', Html)
+class Swagger(Div):
+    def py2js(self):
+        el = document.getElementById('swagger-ui')
+        ui = SwaggerUIBundle({
+            url: el.attributes['schema-url'].value,
+            dom_id: '#swagger-ui',
+            deepLinking: true,
+            presets: [
+                SwaggerUIBundle.presets.apis,
+                SwaggerUIStandalonePreset,
+            ],
+            plugins: [
+                SwaggerUIBundle.plugins.DownloadUrl
+            ],
+            layout: "StandaloneLayout"
+        })
+        window.ui = ui
+
+    def to_html(self, **context):
+        registry = context['view'].registry
+        return super().to_html(
+            Script(src='/static/swagger-ui-bundle.js'),
+            Script(src='/static/swagger-ui-standalone-preset.js'),
+            Stylesheet(href='/static/swagger-ui.css'),
+            Div(
+                id='swagger-ui',
+                schema_url=registry.views['schema'].url,
+            ),
+            **context
+        )
+
+
 @template('crudlfap/home.html', App)
 class Home(Div):
     def to_html(self, **context):
@@ -706,14 +739,11 @@ class mdcDrawer(Aside):
         from .site import site
 
         menu_content = []
+        if request.user.is_authenticated:
+            menu_content.append(MDCListItem(str(request.user.email)))
         for view in site.get_menu('main', request):
-            router = getattr(view, 'router', None)
-            if router:
-                icon = getattr(router, 'icon', None)
-                title = getattr(view, 'model_verbose_name', view.title)
-            else:
-                icon = getattr(view, 'icon', None)
-                title = getattr(view, 'title', '')
+            icon = getattr(view, 'icon', None)
+            title = getattr(view, 'title', '')
 
             menu_content.append(
                 A(
